*************************************************
*||                                           ||*
*||    SSS   TTTTT  AAAAA  TTTTT   AAAAA      ||*
*||   SS       T    A   A    T     A   A      ||*
*||    SSS     T    AAAAA    T     AAAAA      ||*
*||      SS    T    A   A    T     A   A      ||*
*||   SSS      T    A   A    T     A   A      ||*
*||                                           ||*
*************************************************
*                                               *
* Welcome to Tutorial for IV (STATA)            *
* Created by: Anran Liu (UC Davis);             *
*             Yiqing Xu (Stanford)              *
* Latest update: Aug. 17, 2024                  *
* Date*: May. 31, 2023                          *
*                                               *
*************************************************

/* 
Reference: 

Lal, Apoorva, et al. "How Much Should We Trust Instrumental Variable Estimates in Political Science? Practical Advice Based on 67 Replicated Studies." Political Analysis (2024): 1-20. 
*/

*##############################################################*

*                        Install Packages                      *

*##############################################################*

/* ** ivreg2 ** */
/* Step 1: In the console, type: findit ivreg2 */
/* Step 2: Click "st0030_2" to install */
/* Step 3: If an old version exists, force to replace it */

/* ** condivreg ** */
/* Step 1: In the console, type: findit condivreg */
/* Step 2: Click "st0033_2" to install */
/* Step 3: If an old version exists, force to replace it */

/* ** bsweights ** */
/* Step 1: In the console, type: findit bsweights */
/* Step 2: Click "st0187" to install */
/* Step 3: If an old version exists, force to replace it */

/* ** bs4rw ** */




/* Step 1: In the console, type: search bs4rw */
/* Step 2: Download bs4rw from the specified URL (usually requires manual download and installation if not available through SSC or official Stata sites) 
e.g. bs4rw from http://www.stata.com/users/jpitblado */
/* Step 3: If an old version exists, force to replace it */

/* ** plausexog ** */
/* Step 1: In the console, type: ssc install plausexog */
/* Step 2: If an old version exists, use ssc install plausexog, replace */


*-----------------------------------------------------------*

clear all
set more off
cap log close


cd "" // set your path

graph set window fontface "Times New Roman"


*##############################################################*

*                    Estimation and Inference                  *

*##############################################################*


*==============================================================*
*                  Visualizing the first stage                 *
*==============================================================*

use "ajps_Rueda_2017.dta", clear

global D "lm_pob_mesa"
global Y "e_vote_buying"
global Z "lz_pob_mesa_f"
global controls "lpopulation lpotencial"
global cl "muni_code"


*******************
* Raw scatter plot
*******************

scatter $D $Z, mcolor(black) msize(small) msymbol(Oh) || ///
   lfit $D $Z, lcolor(red) lwidth(medium) lpattern(dash) ///
   xtitle("Instrument") ytitle("Treatment") title("Raw Data")

   
***************************
* First stage (partial out)
***************************

qui reg $Z $controls
qui predict z_res, residuals

qui reg $D $controls
qui predict d_res, residuals

* Scatter plot with residualized data
scatter d_res z_res, mcolor(black) msize(small) msymbol(Oh)|| ///
   lfit d_res z_res, lcolor(red) lwidth(medium) lpattern(dash) ///
   xtitle("Residualized Instrument") ytitle("Residualized Treatment") title("Covariates Partialled Out")  

*==============================================================*
*                       Relevant commands                      *
*==============================================================*

/*
The command `ivregress` and `ivreg2` conduct both OLS and 2SLS estimation and quantify uncertainty using multiple inferential methods. They also output relevant information such as the first-stage F-statistics and results from the AR test. In addition, we have written other programs to implement similar functions as `ivDiag` in R.
*/


****************************************
* OLS estimation and inferential results
****************************************

/*
Matrixs `OLS` stores OLS results from the linear model, along with inferetial resutls based on analytic SEs and two (block-) bootstrap methods: the coefficient method (bootstrap-c) and t-ratio method (bootstrap-t).
*/

****************Run OLS regression
qui reg $Y $D $controls, cluster($cl)
mat A = r(table)
matrix OLS1 = (A[1,1], A[2,1], A[3,1], A[5,1], A[6,1], A[4,1])
matrix colnames OLS1 = Coef SE t CI_2.5% CI_97.5% p_value
matlist OLS1

/*
Note: *You can use `esttab` or other commands to show the result rather than using `matrix`. To be consistent with the results of the Tutorial (R), the Tutorial (Stata) chooses this way.
*/

****************Boot.c

// Perform bootstrapping with 1000 replications for OLS and 2SLS
set seed 12345
qui bootstrap _b, reps(1000): reg $Y $D $controls, cluster($cl)
mat A = r(table)
matrix OLS2 =(A[1,1], A[2,1], A[3,1], A[5,1], A[6,1], A[4,1])
matrix colnames OLS1 = Coef SE t CI_2.5% CI_97.5% p_value
matlist OLS2


****************Boot.t

qui bootstrap, reps(1000): reg $Y $D $controls, cluster($cl)
scalar t_stat = _b[$D] / _se[$D]
scalar b_se = _se[$D]
scalar OLS_rf_ci_lower = _b[$D] - invnormal(0.975) * _se[$D]
scalar OLS_rf_ci_upper = _b[$D] + invnormal(0.975) * _se[$D]

// Bootstrap refined p-value
local nboot = _N 

// assuming you have run the bootstrap in Stata and the dataset contains the bootstrap results
qui count if abs(_b[$D]/_se[$D]) < invnormal(0.975)
scalar OLS_rf_p = r(N) / `nboot'
	
qui reg $Y $D $controls 
mat A = r(table)
matrix OLS3 =(A[1,1], A[2,1], A[3,1], OLS_rf_ci_lower, OLS_rf_ci_upper, OLS_rf_p)
matrix colnames OLS3 = Coef SE t CI_2.5% CI_97.5% p_value
matlist OLS3


****************Results

matrix OLS = OLS1\OLS2\OLS3
    matrix colnames OLS = Coef SE t CI_2.5% CI_97.5% p_value
    matrix rownames OLS = Analytic Boot_c Boot_t

matlist OLS


**********************************************
* IV (2SLS) estimation and inferential resutls
**********************************************

/*
Matrixs `IV` stores 2SLS results, along with analytic SEs and two bootstrapped SEs.
*/

****************Run ivregress to perform 2SLS regression

qui ivregress 2sls $Y ($D = $Z) $controls, cluster($cl)

// Store 2SLS results
estimates store iv
mat A = r(table)
matrix IV1 =(A[1,1], A[2,1], A[3,1], A[5,1], A[6,1], A[4,1])
matrix colnames OLS = Coef SE t CI_2.5% CI_97.5% p_value
matlist IV1


****************Boot.c

qui bootstrap _b, reps(1000): ivregress 2sls $Y ($D = $Z) $controls, cluster($cl)
estimates store iv_boot_c

mat A = r(table)
matrix IV2 =(A[1,1], A[2,1], A[3,1], A[5,1], A[6,1], A[4,1])
matrix colnames OLS = Coef SE t CI_2.5% CI_97.5% p_value
matlist IV2


****************Boot.t

qui bootstrap, reps(1000): ivregress 2sls $Y ($D = $Z) $controls, cluster($cl)
scalar t_stat = _b[$D] / _se[$D]
scalar b_se = _se[$D]
scalar IV_rf_ci_lower = _b[$D] - invnormal(0.975) * _se[$D]
scalar IV_rf_ci_upper = _b[$D] + invnormal(0.975) * _se[$D]

local nboot = _N 
qui count if abs(_b[$D]/_se[$D]) < invnormal(0.975)
scalar IV_rf_p = r(N) / `nboot'

qui ivregress 2sls $Y ($D = $Z) $controls, cluster($cl)
mat A = r(table)
matrix IV3 =(A[1,1], A[2,1], A[3,1], IV_rf_ci_lower, IV_rf_ci_upper, IV_rf_p)
matrix colnames IV3 = Coef SE t CI_2.5% CI_97.5% p_value
matlist IV3


*****************Results

matrix IV = IV1\IV2\IV3
    matrix colnames IV = Coef SE t CI_2.5% CI_97.5% p_value
    matrix rownames IV = Analytic Boot_c Boot_t

matlist IV

/*
Two additional inferential methods are provided. AR stores results from the AR test, including the test statistic, the p-value, the 95% CI using the inversion method proposed by Chernozhukov and Hansen (2008), and whether the CI is bounded. 
*/


******************** AR

// Perform the Anderson-Rubin Wald test using condivreg
condivreg $Y ($D = $Z) $controls, ar 
mat A = r(table)
matrix IV_AR =(A[1,1], A[2,1], A[3,1], A[5,1], A[6,1], A[4,1])
matrix colnames IV_AR = Coef SE t CI_2.5% CI_97.5% p_value
matlist IV_AR

/*
`tF` stores results from the tF procedure based on Lee et al. (2022). tF is the critical value for the valid t test adjusted based on the effective F statistic. The CIs are constructed based on tF$t, tF$SE, and tF$cF.
*/

* tF-CF procedure
capture program drop tF
program define tF
  args coef se Fstat
  scalar tstat = coef / se
  
  matrix cF0 = (18.66, 9.74, 7.37, 6.18, 5.43, 4.92, 4.54, 4.25, 4.01, 3.82, 3.65, 3.51, 3.39, 3.29, 3.19, 3.11, 3.03, 2.97, 2.91, 2.85, 2.80, 2.75, 2.71, 2.67, 2.63, 2.60, 2.57, 2.54, 2.51, 2.48, 2.46, 2.43, 2.41, 2.39, 2.37, 2.35, 2.33, 2.32, 2.30, 2.29, 2.27, 2.26, 2.24, 2.23, 2.22, 2.21, 2.20, 2.19, 2.17, 2.16, 2.16, 2.15, 2.14, 2.13, 2.12, 2.11, 2.10, 2.10, 2.09, 2.08, 2.08, 2.07, 2.06, 2.06, 2.05, 2.04, 2.04, 2.03, 2.03, 2.02, 2.02, 2.01, 2.01, 2.00, 2.00, 1.99, 1.99, 1.99, 1.98, 1.98, 1.97, 1.97, 1.97, 1.96)

scalar F_sqrt = sqrt(Fstat)

  if F_sqrt < 2 {
    scalar cF = cF0[1,1]
  } 
  else {

	scalar poss = 0
    foreach value of numlist 2(0.1)10.3 {
      if `value' < F_sqrt {
        scalar poss = poss + 1
      }
      else {
        break
      }
    }
    scalar cF =  cF0[1,poss]
  }

  scalar ci_lower = coef - cF * se
  scalar ci_upper = coef + cF * se
  scalar p = 2 * (1 - normal(abs(tstat) / (cF / 1.96)))  // adjusted p value

  * Display results
  di "F: " Fstat
  di "cF: " cF
  di "Coef: " coef
  di "SE: " se
  di "t: " tstat
  di "CI 2.5%: " ci_lower
  di "CI 97.5%: " ci_upper
  di "p: " p
end

*-----------------------------
ivreg2 $Y ($D = $Z) $controls, cluster($cl)
estimates store mymodel

scalar coef = _b[$D]
scalar se = _se[$D]
scalar Fstat = e(widstat)

//Results
tF

matrix IV_tF = [coef, se, tstat, ci_lower, ci_upper, p]
    matrix colnames IV_tF = Coef SE t CI_2.5% CI_97.5% p_value

matlist IV_tF
 
 
*******************************
* Charaterizing the first stage
*******************************

/*
F_stat stores various first-stage partial F-statistics, which assess the strength of the instruments. They include F statistic based classic analytic SEs, robust SEs, cluster-robust SEs (if `cl` is supplied), (blocked-)bootstrapped F statistic, and the effective F statistic (Olea and Pflueger 2013).
*/


****************** F statistics

qui ivreg2 $Y ($D = $Z) $controls
scalar F_standard = e(cdf) //Cragg-Donald Wald F statistic 

*------------------------------

qui ivreg2 $Y ($D = $Z) $controls, robust
scalar F_robust = e(rkf) //Kleibergen-Paap Wald rk F statistic  

*------------------------------

qui ivreg2 $Y ($D = $Z) $controls, cluster($cl)
scalar F_cluster = e(rkf) 

*------------------------------

set seed 14567
bootstrap, reps(1000): regress $D $Z $controls, cluster($cl)
matrix V = e(V)
mat A = r(table)

matrix V_sub =(V[1,1], V[1,2], V[1,3] ///
 \ V[2,1], V[2,2], V[2,3] ///
 \ V[3,1], V[3,2], V[3,3])

matrix V_inv = inv(V_sub)
matlist V_inv
scalar pz = 1 //The number of excluded IV

mat pai = (A[1,1], A[1,2], A[1,3])
matlist pai

matrix F_boot = (pai * V_inv * pai') / pz
scalar F_bootstrap = el(F_boot,1,1)

*------------------------------

qui ivreg2 $Y ($D = $Z) $controls, cluster($cl)
scalar F_effective = e(widstat)

/*
* Another way *
ssc install weakivtest
qui ivreg2 $Y ($D = $Z) $controls, cluster($cl)
weakivtest
scalar F_effective = r(F_eff)  // Montiel-Pflueger effective F statistic 
*/

scalar list F_standard F_robust F_cluster F_bootstrap F_effective
 
 
************************rho
qui reg $D $Z $controls, robust
cap drop rho_predicted
predict rho_predicted
qui pcorr $D rho_predicted $controls

matrix rho = r(p_corr)[1,1]
matrix list rho
 
 
****************************
* Other relevant information
****************************

/*
Matrix `rf` stores results from the reduced form regression. SEs and CIs are produced similarly as in matrix `rf`.
*/
 
 
*****************Reduced form

qui reg $Y $Z $controls, robust
mat A = r(table)
matrix rf =(A[1,1], A[2,1], A[3,1], A[5,1], A[6,1], A[4,1])
matrix colnames rf = Coef SE t CI_2.5% CI_97.5% p_value
matlist rf
 
/*
Matrix `fs` stores the number of instruments. `N` and `N_cl` store the number of observations and the number of clusters used in the OLS and 2SLS regression, respectively. `df` stores the degree of freedom left from the 2SLS regression. The nvalues stores the unique values the outcome Y, the treatment D, and each instrument in Z in the 2SLS regression.
*/
 
 
*******************First stage

qui reg $D $Z $controls, robust
mat A = r(table)
matrix fs =(A[1,1], A[2,1], A[3,1], A[5,1], A[6,1], A[4,1])
matrix colnames rf = Coef SE t CI_2.5% CI_97.5% p_value、
matlist fs

*--------------------------------
qui ivreg2 $Y ($D = $Z) $controls

scalar p_IV = e(endog_ct)

scalar N = e(N)

scalar df = e(Fdf2)

qui ivreg2 $Y ($D = $Z) $controls, cluster($cl)

scalar N_cl =  e(N_clust)

scalar list p_IV N N_cl df

 
***************************
* Coefficients and CIs plot
***************************

 
***********************Plot

matrix Plot = OLS\IV\IV_AR\IV_tF
    matrix colnames Plot = Coef SE t CI_2.5% CI_97.5% p_value
    matrix rownames Plot = OLS_Analytic OLS_Boot_c OLS_Boot_t IV_Analytic IV_Boot_c IV_Boot_t AR TF
coefplot matrix(Plot[,1]), ci((Plot[,4] Plot[,5])) xscale(range(-1.5 0))
 
 
 
*##############################################################*
  
*                       Sensitivity Tests                      *

*##############################################################*


*==============================================================*
*              The persistence of social captial               *
*==============================================================*

/*
We illustrate the diagnostics by applying it to the IV analysis in Guiso, Sapienza, and Zingales (2016) (henceforth GSZ 2016), who revisit Putnam, Leonardi, and Nanetti (1992)'s celebrated conjecture that Italian cities that achieved self-government in the Middle Ages have higher modern-day levels of social capital. More specifically, they study the effects of free city-state status on social capital as measured by the number of nonprofit organizations and organ donations per capita, and a measure of whether students cheat in mathematics. Below is a summary. In this tutorial, we focus on the first outcome.

Using the replication data, we first locate the key variables and take a look at the data. The outcome variable is highly skewed, but we keep it as is to be consistent with the original paper.
*/


* Table instrument
 
use gsz.dta, clear
global Y "totassoc_p"
global D "libero_comune_allnord"
global Z "bishopcity"
global weights "population"
global controls "altitudine escursione costal nearsea population pop2 gini_land gini_income"

tabulate $Z
tabulate $D
tabulate $Z $D

* Distribution of the outcome
histogram $Y, bin(100) xtitle("Nonprofit Organizations Per Capita")
 
****************************************
* OLS estimation and inferential results
****************************************

/*
Matrixs `OLS`' stores OLS results from the linear model, along with inferetial resutls based on analytic SEs and two (block-)bootstrap methods: the coefficient method (bootstrap-c) and t-ratio method (bootstrap-t).
*/
 
qui reg $Y $D $controls [pw = $weights]
estimates store ols
mat A = r(table)
matrix OLS1 =(A[1,1], A[2,1], A[3,1], A[5,1], A[6,1], A[4,1])
 

qui cap drop bsw*
qui bsweights bsw, reps(1000) n(50) nosvy balanced 
qui bs4rw, rw(bsw*): reg $Y $D $controls [pw = $weights]
mat A = r(table)
matrix OLS2 =(A[1,1], A[2,1], A[3,1], A[5,1], A[6,1], A[4,1])
 
 
qui cap drop bsw*
qui bsweights bsw, reps(1000) n(50) nosvy balanced 
qui bs4rw, rw(bsw*): reg $Y $D $controls [pw = $weights]
scalar t_stat = _b[$D] / _se[$D]
scalar b_se = _se[$D]
scalar OLS_rf_ci_lower = _b[$D] - invnormal(0.975) * _se[$D]
scalar OLS_rf_ci_upper = _b[$D] + invnormal(0.975) * _se[$D]
local nboot = _N 
qui count if abs(_b[$D]/_se[$D]) < invnormal(0.975)
scalar OLS_rf_p = r(N) / `nboot'
qui reg $Y $D $controls [pw = $weights]
mat A = r(table)
matrix OLS3 =(A[1,1], A[2,1], A[3,1], OLS_rf_ci_lower, OLS_rf_ci_upper, OLS_rf_p)
matrix colnames OLS3 = Coef SE t CI_2.5% CI_97.5% p_value
matlist OLS3

matrix OLS = OLS1\OLS2\OLS3
    matrix colnames OLS = Coef SE t CI_2.5% CI_97.5% p_value
    matrix rownames  OLS = Analytic Boot_c Boot_t

matlist OLS
 
 
**********************************************
* IV (2SLS) estimation and inferential resutls
**********************************************

qui ivregress 2sls $Y ($D = $Z) $controls [pw = $weights], robust
mat A = r(table)
matrix IV1 =(A[1,1], A[2,1], A[3,1], A[5,1], A[6,1], A[4,1])

****************Boot.c

cap program drop iv_bootstrap_weighted
program define iv_bootstrap_weighted, rclass
    syntax, y(varname) d(varname) z(varname) controls(varlist) [weights(varname)] [cluster(varname)]
    ivreg2 `y' (`d' = `z') `controls' [pw =`weights'], robust
end
qui bootstrap _b, saving(bootstrap2, replace) reps(1000) nodots: iv_bootstrap_weighted, y($Y) d($D) z($Z) controls($controls) weights($weights)

mat A = r(table)
mat list A
matrix IV2 =(A[1,1], A[2,1], A[3,1], A[5,1], A[6,1], A[4,1])

****************Boot.t

qui bootstrap _b, saving(bootstrap2, replace) reps(1000) nodots: iv_bootstrap_weighted, y($Y) d($D) z($Z) controls($controls) weights($weights)
scalar t_stat = _b[$D] / _se[$D]
scalar b_se = _se[$D]
scalar IV_rf_ci_lower = _b[$D] - invnormal(0.975) * _se[$D]
scalar IV_rf_ci_upper = _b[$D] + invnormal(0.975) * _se[$D]

local nboot = _N 
qui count if abs(_b[$D]/_se[$D]) < invnormal(0.975)
scalar IV_rf_p = r(N) / `nboot'

qui ivregress 2sls $Y ($D = $Z) $controls [pw = $weights], robust
mat A = r(table)
matrix IV3 =(A[1,1], A[2,1], A[3,1], IV_rf_ci_lower, IV_rf_ci_upper, IV_rf_p)
matrix colnames IV3 = Coef SE t CI_2.5% CI_97.5% p_value
matlist IV3


*******************Results

matrix IV = IV1\IV2\IV3
    matrix colnames IV = Coef SE t CI_2.5% CI_97.5% p_value
    matrix rownames  IV = Analytic Boot_c Boot_t

matlist IV


* tF-CF procedure
qui ivreg2 $Y ($D = $Z) $controls [pw = $weights]
estimates store mymodel

scalar coef = _b[$D]
scalar se = _se[$D]
scalar Fstat = e(widstat)

tF

matrix IV_tF = [coef, se, tstat, ci_lower, ci_upper, p]
    matrix colnames IV_tF = Coef SE t CI_2.5% CI_97.5% p_value

matlist IV_tF
 

*******************************
* Charaterizing the first stage
*******************************


*******************F statistics

qui ivreg2 $Y ($D = $Z) $controls [pw = $weights]
scalar F_standard = e(cdf) //Cragg-Donald Wald F statistic 

*------------------------------

qui ivreg2 $Y ($D = $Z) $controls [pw = $weights]
scalar F_robust = e(rkf) //Kleibergen-Paap Wald rk F statistic  

*------------------------------

cap program drop my_ivreg2_weighted
program define my_ivreg2_weighted, rclass
    syntax, d(varname) z(varname) controls(varlist) [weights(varname)] [cluster(varname)]
    regress `d' `z' `controls' [pw =`weights']
    return scalar Fstat = e(rkf)
end
bootstrap, reps(100): my_ivreg2_weighted, d($D) z($Z) controls($controls) weights($weights)

matrix V = e(V)
mat A = r(table)

matrix V_sub =(V[1,1], V[1,2], V[1,3] ///
 \ V[2,1], V[2,2], V[2,3] ///
 \ V[3,1], V[3,2], V[3,3])

matrix V_inv = inv(V_sub)
matlist V_inv
scalar pz = 1 //The number of excluded IV

mat pai = (A[1,1], A[1,2], A[1,3])
matlist pai

matrix F_boot = (pai * V_inv * pai') / pz
scalar F_bootstrap = el(F_boot,1,1)

*------------------------------

qui ivreg2 $Y ($D = $Z) $controls  [pw = $weights]
estimates store mymodel
scalar F_effective = e(widstat)  // Montiel-Pflueger effective F statistic 


scalar list F_standard F_robust F_bootstrap F_effective
 
 
************************rho

reg $D $Z $controls [aw=$weights]
cap drop rho_predicted
predict rho_predicted
pcorr $D rho_predicted $controls [aw=$weights]
matrix rho = r(p_corr)[1,1]
matrix list rho
 
 
****************************
* Other relevant information
****************************


*************** Reduced form

qui reg $Y $Z $controls [pw = $weights]

mat A = r(table)

matrix rf =(A[1,1], A[2,1], A[3,1], A[5,1], A[6,1], A[4,1])
    matrix colnames rf = Coef SE t CI_2.5% CI_97.5% p_value

matlist rf
 
 
*****************First stage

qui reg $D $Z $controls [pw = $weights]

mat A = r(table)

matrix fs =(A[1,1], A[2,1], A[3,1], A[5,1], A[6,1], A[4,1])
    matrix colnames rf = Coef SE t CI_2.5% CI_97.5% p_value、

matlist fs


*----------------------------
qui ivreg2 $Y ($D = $Z) $controls [pw = $weights]

scalar p_IV = e(endog_ct)

scalar N = e(N)

scalar df = e(Fdf2)

qui ivreg2 $Y ($D = $Z) $controls [pw = $weights]

scalar list p_IV N df

 
***************************
* Coefficients and CIs plot
***************************

 
***********************Plot

matrix Plot = OLS\IV\IV_tF
    matrix colnames Plot = Coef SE t CI_2.5% CI_97.5% p_value
    matrix rownames Plot = OLS_Analytic OLS_Boot_c OLS_Boot_t IV_Analytic IV_Boot_c IV_Boot_t TF

coefplot matrix(Plot[,1]), ci((Plot[,4] Plot[,5]))  
 
 

*==============================================================*
*                 ZFS tests and LTZ adjustment                 *
*==============================================================*

use gsz_south.dta, clear

* Set variable names
global Y "totassoc_p"
global Z "bishopcity"
global weights "population"
global controls "altitudine escursione costal nearsea population pop2 gini_land gini_income capoluogo"


reg $Y $Z $controls [pw = $weights]
 

/*
Setting 0.178 as the prior mean and 0.137 as its standard deviation (SD), we can perform a LTZ adjustment on the 2SLS/IV estimate.
*/
 
*********************************************************************
 
use gsz.dta, clear
* Set variable names
global Y "totassoc_p"
global D "libero_comune_allnord"
global Z "bishopcity"
global weights "population"
global controls "altitudine escursione costal nearsea population pop2 gini_land gini_income"

// Original 2SLS/IV estimate
ivreg2 $Y ($D = $Z) $controls [pw = $weights]

// A LTZ adjustment on the 2SLS/IV estimate
plausexog ltz $Y $controls ($D = $Z) [pw = $weights], mu(0.178) omega(0.137) level(0.975)
 
 
*********************************************************************

use gsz_south.dta, clear
global controls "altitudine escursione costal nearsea population pop2 gini_land gini_income capoluogo"

capture program drop plot_ltz
program define plot_ltz
	args coef se lower_ci upper_ci
	twoway function y=normalden(x, `coef', `se'), ///
        range(-1 7) lpattern(dash) xline(`coef', lc(black*0.5) ) ///
        xline(`lower_ci', lc(black*0.5) lp(dash)) ///
        xline(`upper_ci', lc(black*0.5) lp(dash)) ///
		xtitle("") ytitle("") /// 
		xlabe(-1(2)7)
end


qui regress $Y $Z $controls [pw = $weights]   
local coef = _b[$Z]
local se = _se[$Z]
local lower_ci = `coef' - 1.96 * `se'
local upper_ci = `coef' + 1.96 * `se'

plot_ltz `coef' `se' `lower_ci' `upper_ci'

 
*********************************************************************

use gsz.dta, clear
global controls "altitudine escursione costal nearsea population pop2 gini_land gini_income"

qui ivregress 2sls $Y ($D = $Z) $controls [pw = $weights]   
local coef = _b[$D]
local se = _se[$D]
local lower_ci = `coef' - 1.96 * `se'
local upper_ci = `coef' + 1.96 * `se'

plot_ltz `coef' `se' `lower_ci' `upper_ci'

 
*********************************************************************

use gsz.dta, clear
global controls "altitudine escursione costal nearsea population pop2 gini_land gini_income"
ivreg2 $Y ($D = $Z) $controls [pw = $weights]

plausexog ltz $Y $controls ($D = $Z) [pw = $weights], mu(0.178) omega(0.137) level(.95) 
local coef = _b[$D]
local se = _se[$D]
local lower_ci = `coef' - 1.96 * `se'
local upper_ci = `coef' + 1.96 * `se'

plot_ltz `coef' `se' `lower_ci' `upper_ci'



* ---------------- End of do-file -------------- *

* /**********************************************\
* |             Analysis Completed.              |
* |             Thank You for Using              |
* |           Tutorial for IV (STATA).           |
* \**********************************************/

* /********************* Info *******************\
* |  For comments or questions, please contact:  |
* |            Anran Liu, anrliu@ucdavis.edu     |
* |            All rights reserved.              |
* \**********************************************/

* ---------------------------------------------- *

